/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package samples;

import java.io.File;
import java.io.FileInputStream;
import java.util.Iterator;
import java.util.List;

// Zeus imports
import org.enhydra.zeus.Binder;
import org.enhydra.zeus.Binding;
import org.enhydra.zeus.Generator;
import org.enhydra.zeus.Result;
import org.enhydra.zeus.binder.DTDBinder;
import org.enhydra.zeus.binding.Container;
import org.enhydra.zeus.binding.Property;
import org.enhydra.zeus.generator.SimpleGenerator;
import org.enhydra.zeus.result.StreamResult;
import org.enhydra.zeus.source.DTDSource;
import org.enhydra.zeus.source.StreamDTDSource;

import org.enhydra.zeus.util.Arguments;

public class TestDTDBinder {

    public static void main(String[] args) {
        Arguments theArguments = new Arguments(args);

        // Using Arguments, parameters can be sent in any order
        if (!theArguments.hasValue("file")) {
            System.out.println(
                "Usage: java samples.TestDTDBinder -file=<file name> " +
                    "[-package=<package>]  [-quiet=true/false] " +
                    "[-generateAsSerializable=true/false]");
            return;
        }

        try {
            String thePackage = null;
            if (theArguments.hasValue("package")) {
                thePackage = theArguments.getValue("package");
            } else {

                // Set the package to the default package if not specified.
                thePackage = "";
            }

            // This is to match the original default action
            boolean isQuiet = false;
            if (theArguments.hasValue("quiet")) {
                isQuiet = theArguments.getValue("quiet")
                                      .trim()
                                      .equalsIgnoreCase("true");
            }

            // Get handle to the DTD
            File dtd = new File(theArguments.getValue("file"));
            DTDSource source = new StreamDTDSource(new FileInputStream(dtd));

            if (!isQuiet) {
                System.out.println("Generating bindings...");
            }

            // Get the Zeus Bindings
            Binder dtdBinder = new DTDBinder(source);
            List bindings = dtdBinder.getBindings();

            if (!isQuiet) {
                System.out.println("Bindings generated...\n\n");
            }

            // Do some printing
            if (!isQuiet) {
                for (Iterator i = bindings.iterator(); i.hasNext();) {
                    Binding binding = (Binding) i.next();
                    System.out.println("Binding");
                    System.out.println("  Type: " + 
                        binding.getClass().getName());
                    System.out.println("  Name: " + binding.getJavaName());
                    System.out.println("  Properties");

                    try {
                        Container container = (Container) binding;
                        List properties = container.getProperties();
                        if (properties.size() > 0) {
                            for (Iterator j = properties.iterator(); 
                                 j.hasNext();) {
                                Property property = (Property) j.next();
                                System.out.println("    Name: " + 
                                    property.getJavaName());
                                System.out.println("    Type: " + 
                                    property.getJavaType());
                            }
                        } else {
                            System.out.println("    (None)");
                        }
                    } catch (ClassCastException e) {
                        System.out.println("    (None)");
                    }
                    System.out.println();
                }
                System.out.println("--------------------------------------");
                System.out.println(
                    "Finished testing Binding Generation...\n\n");
                System.out.println("--------------------------------------");
                System.out.println("Going to test Class Generation...\n");
            }

            Generator generator = new SimpleGenerator();
            generator.setJavaPackage(thePackage);
            generator.setOutputDirectory(new File("output"));
            String generateAsSerializable = 
                (String)theArguments.getValue("generateAsSerializable");
            if ((generateAsSerializable != null) && 
                (generateAsSerializable.equalsIgnoreCase("true"))) {

                generator.setGenerateAsSerializable(true);
            }
            for (Iterator i = bindings.iterator(); i.hasNext();) {

                if (!isQuiet) {
                    System.out.println("--------------------------------");
                }

                Binding binding = (Binding) i.next();
                generator.generate(binding);

                if (!isQuiet) {
                    System.out.println("--------------------------------");
                }
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
