/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package samples;

import java.io.File;
import java.io.FileInputStream;
import java.lang.reflect.Method;

// Zeus imports
import org.enhydra.zeus.Source;
import org.enhydra.zeus.Unmarshaller;
import org.enhydra.zeus.source.StreamSource;

public class TestUnmarshaller {

    public static void main(String[] args) {
        if (args.length < 1) {
            System.out.println("Usage: java samples.TestUnmarshaller " +
                "[XML filename] [package]");
            return;
        }

        try {
            String thePackage = null;
            if (args.length > 1) {
                thePackage = args[1];
            } else {

                // Set the package to the default package if not specified.
                thePackage = "";
            }

            Source source = new StreamSource(
                new FileInputStream(new File(args[0])));
            Unmarshaller unmarshaller = new Unmarshaller();
            unmarshaller.setJavaPackage(thePackage);
            Object o = unmarshaller.unmarshal(source).getObject();

            // Introspect the returned object
            System.out.println("Generated class of type " + 
                o.getClass().getName());
            System.out.println("Methods available:");
            Method[] methods = o.getClass().getDeclaredMethods();
            for (int i=0; i<methods.length; i++) {
                Method method = methods[i];
                System.out.print("  " + method.getReturnType().getName() +
                    " " + method.getName() + "(");
                Class[] params = method.getParameterTypes();
                for (int j=0; j<params.length; j++) {
                    System.out.print(params[j].getName());
                    if (j+1 < params.length) {
                        System.out.print(", ");
                    }
                }
                System.out.println(");");
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
