package org.enhydra.zeus.util;

/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */

import java.util.Hashtable;

/**
 * <p>
 *  <code>Arguments</code> is a Zeus utility class that provides
 *    for converting arguments passed to a class in the -param=value
 *    format into a <code>Hashtable</code> like container.  This makes
 *    it possible to pass arguments in any order.
 * </p>
 *
 * @author Brooke Hedrick
 * @version 1.0
 */
public class Arguments extends Hashtable {
    
    /**
     * <p>Constructor to delegate instantiation.</p>
     */
    public Arguments() {
        super();
    }
    
    /**
     * <p>This will take the arguments passed to a main method with the arguments specified as
     * -argument1=value -argument2=value and place these in a <code>Hashtable</code>
     * keyed by the argument name.</p>
     *
     * @param args <code>String[]</code> initial arguments to add.
     */
    public Arguments(String[] args) {
        super();
        setValues(args);
    }
    
    /**
     * <p>
     *  This will take a <code>String</code> as the argument name,
     *    and return the parameter value. 
     * </p>
     *
     * @param argument <code>String</code> argument to find.
     * @return <code>String</code> - the value of the argument.
     */
    public String getValue(String argumentName) {
        return (String)get(argumentName);
    }
    
    /**
     * <p>
     *  This will take a <code>String</code> as the argument name,
     *    and return true if an argument by that name exists, otherwise. 
     *    it will return false</p>
     *
     * @param argumentName <code>String</code> argument to find.
     * @return <code>boolean</code> - whether or not the argument exists.
     */
    public boolean hasValue(String argumentName) {
        return (get(argumentName) != null);
    }
    
    /**
     * <p>
     *  This will take a <code>String</code> as the argument name,
     *    and another <code>String</code> as the argument value in. 
     *    order to add a new argument/value to the list of arguments</p>
     *
     * @param argumentName <code>String</code> argument to add.
     * @param argumentValue <code>String</code> value of argument.
     */
    public void setValue(String argumentName, String argumentValue) {
        put(argumentName, argumentValue);
    }
    
    /**
     * <p>
     *  This will take a <code>String[]</code> as an array of -argument=value pairs
     *    and add to/update the <code>Hashtable</code> containing the arguments.</p>
     *
     * @param args <code>String[]</code> argument pairs to add/update
     */
    public void setValues(String[] args) {
        int equalsPosition = -1;

        for (int i = 0; i < args.length; i++) {
            String arg = args[i];
            equalsPosition = arg.indexOf("=");

            /**
             * This check was added by 
             * Richard Kasperowski, kasper@altisimo.com
             */
            if ( equalsPosition == -1 ) {
                System.err.println("The argument you specified, '"
                    + arg + "' doesn't contain an '='.\n"
                    + "All arguments must be of the form 'foo=bar'.");
                System.exit(1);
            }

            put(arg.substring(1, equalsPosition), arg.substring(equalsPosition + 1));
        }
    }
}

