/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

/**
 * <p>
 *  <code>Capitalization</code> is a Zeus utility class that provides
 *    for converting lowercase letters to uppercase ones, uppercase ones
 *    to lowercase ones, and more generally, converting Java 
 *    <code>String</code>s from an unknown format to initial caps (where
 *    only the first letter is capitalized), making a suitable class or
 *    variable name.
 * </p>
 *
 * @author Brett McLaughlin
 * @version 1.0
 */
public class CapitalizationUtils {

    /**
     * <p>
     *  This will take a <code>String</code> with unknown capitalization,
     *    and convert the first letter to a capital letter, while leaving
     *    all other letters the same. Note that if you want the rest of
     *    the letters converted to lowercase, then
     *    <code>{@link #justInitialUpper(String)}</code> should be used.
     * </p>
     *
     * @param original <code>String</code> to convert.
     * @return <code>String</code> - the converted <code>String</code>.
     */
    public static String initialUpper(String original) {        
        char[] originalChars = original.toCharArray();
        char firstLetter = 
            Character.toUpperCase(original.charAt(0));
        originalChars[0] = firstLetter;        
        
        return new String(originalChars);
    }
    
    /**
     * <p>
     *  This will take a <code>String</code> with unknown capitalization,
     *    and convert the first letter to a capital letter, while converting
     *    all other letters to lowercase. Note that if you want the rest of
     *    the letters left alone, then
     *    <code>{@link #initialUpper(String)}</code> should be used.
     * </p>
     *
     * @param original <code>String</code> to convert.
     * @return <code>String</code> - the converted <code>String</code>.
     */    
    public static String justInitialUpper(String original) {
        String lowercaseOriginal = allLower(original);
        return initialUpper(lowercaseOriginal);
    }
    
    /**
     * <p>
     *  This will take a <code>String</code> with unknown capitalization,
     *    and convert all the letters to uppercase letters. 
     *    Note that if you want just the first
     *    letter converted to lowercase, then
     *    <code>{@link #initialUpper(String)}</code> should be used.
     * </p><p>
     *  And for all you geniuses out there, yes, I know that 
     *    <code>toUpperCase()</code> can be used directly; but
     *    placing the code within this method allows this class
     *    to be uniformly used for all capitalization purposes.
     * </p>
     *
     * @param original <code>String</code> to convert.
     * @return <code>String</code> - the converted <code>String</code>.
     */    
    public static String allUpper(String original) {
        return original.toUpperCase();
    }    
    
    /**
     * <p>
     *  This will take a <code>String</code> with unknown capitalization,
     *    and convert the first letter to a lowercase letter, while leaving
     *    all other letters the same. Note that if you want the rest of
     *    the letters converted to lowercase, then
     *    <code>{@link #allLower(String)}</code> should be used.
     * </p>
     *
     * @param original <code>String</code> to convert.
     * @return <code>String</code> - the converted <code>String</code>.
     */
    public static String initialLower(String original) {        
        char[] originalChars = original.toCharArray();
        char firstLetter = 
            Character.toLowerCase(original.charAt(0));
        originalChars[0] = firstLetter;        
        
        return new String(originalChars);
    }
    
    /**
     * <p>
     *  This will take a <code>String</code> with unknown capitalization,
     *    and convert all the letters to lowercase letters. 
     *    Note that if you want just the first
     *    letter converted to lowercase, then
     *    <code>{@link #initialLower(String)}</code> should be used.
     * </p><p>
     *  And for all you geniuses out there, yes, I know that 
     *    <code>toLowerCase()</code> can be used directly; but
     *    placing the code within this method allows this class
     *    to be uniformly used for all capitalization purposes.
     * </p>
     *
     * @param original <code>String</code> to convert.
     * @return <code>String</code> - the converted <code>String</code>.
     */    
    public static String allLower(String original) {
        return original.toLowerCase();
    }    

}