/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

import java.util.Hashtable;
import java.util.Enumeration;

// DTD Parser
import com.wutka.dtd.DTDElement;
import com.wutka.dtd.DTDMixed;
import com.wutka.dtd.DTDPCData;

/**
 * <p>
 *  <code>SchemaUtils</code> provides utility methods specific to DTDs
 *    and code dealing with DTDs.
 * </p>
 *
 * @author  Maciej Zawadzki 
 */
public class DTDUtils {

    /**
     * <p>
     * Helper method to determine whether the specified element is simple.
     * </p>
     */
    public static boolean isSimpleElement(DTDElement element) {
        boolean result = true;
        
        if ((element.getContent() instanceof DTDPCData) || 
            (element.getContent() instanceof DTDMixed)) {
            // get attributes
            Hashtable attributes = element.attributes;
            String key = null;
            // if there are no attributes, than it is simple
            for (Enumeration enum = attributes.keys(); enum.hasMoreElements(); ) {
                key = (String)enum.nextElement();
                // skip attributes whose name starts with "dt_" for now
                // we'll map them to Java types later
                if (!key.startsWith("dt_")) {
                    result = false;
                    break;
                }
            }
        } else {
            result = false;
        }
        return result;
    }
}

