/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

/**
 * <p>
 *  <code>SchemaUtils</code> provides utility methods specific to XML Schema
 *    and code dealing with schemas.
 * </p>
 *
 * @author Brett McLaughlin
 * @version 1.0
 */
public class SchemaUtils {

    /**
     * <p>
     *  This will take as input an XML Schema data type (such as "string")
     *  and convert it to a Java data type (such as "String"). It includes,
     *  if needed, the fully-qualified package (such as "java.util.List") to
     *  prevent import problems.
     * </p>
     * <p><b>Note:</b> Eventually this should probably work in concert with
     *   some methodology that handles package imports and the like.</p>
     *
     * @param schemaType the XML Schema data type (as a <code>String</code>)
     * @return <code>String</code> - the Java data type.
     */
    public static String getJavaType(String schemaType) {
        if (schemaType.equals("string")) {
            return "String";
        }

        // If we got here, it's an unsupported or incorrect data type
        throw new IllegalArgumentException("Unsupported or invalid XML Schema" +
            " data type supplied.");
    }
}
