/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus;

import junit.framework.TestCase;

/**
 * <p>
 * Abstract test case for Binding objects.  This class provides tests for
 * methods on the Binding interface that all Binding subclasses will inherit.
 * </p>
 *
 * <p>
 * Concrete Binding test cases should extend this class, override the
 * createBinding method, and add any tests specific to the class being tested.
 * </p>
 *
 * @author Robert Sese
 * @version 1.0
 */
public abstract class AbstractBindingTest extends TestCase {

    /**
     * Creates a new Binding object that will be used to test Binding methods. 
     *
     * @return a Binding object to test with.
     */
    public abstract Binding createBinding();

    /**
     * Constructs a new AbstractBindingTest.
     *
     * @param name Name of the test case.
     */
    public AbstractBindingTest(String name) {
        super(name);
    }

    /**
     * Tests getting the Java name of a binding.
     */
    public void testGetJavaName() {
        Binding binding = createBinding();
        String expected = "MyName";

        binding.setXMLName(expected);
        assertEquals(expected, binding.getJavaName());
    }

    /**
     * Tests getting the XML name of a binding.
     */
    public void testGetXMLName() {
        Binding binding = createBinding();
        String expected = "MyName";

        binding.setXMLName(expected);
        assertEquals(expected, binding.getXMLName());
    }

    /**
     * Tests setting the XML name of a binding.
     */
    public void testSetXMLName() {
        Binding binding = createBinding();
        String expected1 = "MyName";
        String expected2 = "MyName";

        binding.setXMLName(expected1);
        assertEquals(expected1, binding.getXMLName());
        binding.setXMLName(expected2);
        assertEquals(expected2, binding.getXMLName());
    }

    /**
     * Tests getting the Java type of a binding.
     */
    public void testGetJavaType() {
        Binding binding = createBinding();
        String expected = "MyType";

        binding.setJavaType(expected);
        assertEquals(expected, binding.getJavaType());
    }

    /**
     * Tests setting the Java type of a binding.
     */
    public void testSetJavaType() {
        Binding binding = createBinding();
        String expected1 = "MyType1";
        String expected2 = "MyType2";

        binding.setJavaType(expected1);
        assertEquals(expected1, binding.getJavaType());
        binding.setJavaType(expected2);
        assertEquals(expected2, binding.getJavaType());
    }

}

