/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.binding;

import java.util.BitSet;
import java.util.Vector;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 * Test case for AtomicProperty.
 * </p>
 *
 * @author Robert Sese
 * @version 1.0
 */
public class AtomicPropertyTest extends AbstractPropertyTest {

    /** Enumerated values for the test AtomicProperty. */
    private Vector enumeratedValues;

    /**
     * The modifiers (i.e. public, volatile, etc) for the test AtomicProperty.
     */
    private BitSet modifiers;

    /** The test AtomicProperty. */
    private AtomicProperty atomicProperty;


    /**
     * Creates a new Property object that will be used to test Property level
     * methods.
     *
     * @return a Property object to test with.
     */
    protected Property createProperty() {
        return new AtomicProperty("MyProperty", "MyType");
    }

    /**
     * Constructs an AtomicPropertyTest with the given name.
     *
     * @param name Name of the test case.
     */
    public AtomicPropertyTest(String name) {
        super(name);
    }

    /**
     * Returns the test suite for this test case.
     *
     * @return the TestSuite for AtomicProperty test.
     */
    public static Test suite() {
        return new TestSuite(AtomicPropertyTest.class);
    }

    /**
     * Establishes the test fixture.
     */
    protected void setUp() {
        enumeratedValues = new Vector();
        enumeratedValues.add("Value1");
        enumeratedValues.add("Value2");

        modifiers = new BitSet();
        modifiers.set(Property.ACCESS_PRIVATE);
        modifiers.set(Property.SOURCE_ATTLIST);

        atomicProperty = new AtomicProperty("MyProperty", "MyType");
    }

    /**
     * Releases any resources.
     */
    protected void tearDown() {
        enumeratedValues = null;
        modifiers = null;
        atomicProperty = null;
    }

    /**
     * Tests a valid construction.
     */
    public void testConstructor1() {
        AtomicProperty a = new AtomicProperty("MyProperty", "MyType",
            modifiers, enumeratedValues, "MyDefaultValue");
        assert("Constructor failure", a != null);
    }

    /**
     * Tests a valid construction.
     */
    public void testConstructor2() {
        AtomicProperty a = new AtomicProperty("MyProperty", "MyType");
        assert("Constructor failure", a != null);
    }

    /**
     * Tests a valid construction.
     */
    public void testConstructor3() {
        AtomicProperty a = new AtomicProperty("MyProperty", "MyType",
            modifiers);
        assert("Constructor failure", a != null);
    }
    
}

