/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.binding;

import java.util.BitSet;
import java.util.Vector;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 * Test case for ContainerProperty.
 * </p>
 *
 * <p>
 * Even though ContainerProperty implements both Property and Container,
 * ContainerPropertyTest will only provide a concrete AbstractContainerTest.
 * AtomicPropertyTest already provides a concrete AbstractPropertyTest.
 * </p>
 *
 * @author Robert Sese
 * @version 1.0
 */
public class ContainerPropertyTest extends AbstractContainerTest {

    /**
     * The modifiers (i.e. public, volatile, etc) for the test
     * ContainerProperty.
     */
    private BitSet modifiers;

    /** The test ContainerProperty. */
    private ContainerProperty containerProperty;


    /**
     * Creates a new Container object that will be used to test Container level
     * methods.
     *
     * @return a Container object to test with.
     */
    protected Container createContainer() {
        return new ContainerProperty("MyContainer");
    }

    /**
     * Constructs an ContainerPropertyTest with the given name.
     */
    public ContainerPropertyTest(String name) {
        super(name);
    }

    /**
     * Returns the test suite for this test case.
     *
     * @return the TestSuite for ContainerProperty test.
     */
    public static Test suite() {
        return new TestSuite(ContainerPropertyTest.class);
    }

    /**
     * Establishes the test fixture.
     */
    protected void setUp() {
        modifiers = new BitSet();
        modifiers.set(Property.ACCESS_PRIVATE);
        modifiers.set(Property.SOURCE_ATTLIST);

        containerProperty = new ContainerProperty("MyContainer");
    }

    /**
     * Releases any resources.
     */
    protected void tearDown() {
        modifiers = null;
        containerProperty = null;
    }

    /**
     * Tests a valid construction.
     */
    public void testConstructor1() {
        ContainerProperty c = new ContainerProperty("MyContainer", modifiers, 
            "MyDefaultValue");
        assert("Constructor failure", c != null);
    }

    /**
     * Tests a valid construction.
     */
    public void testConstructor3() {
        ContainerProperty c = new ContainerProperty("MyContaienr");
        assert("Constructor failure", c != null);
    }
    
}

