/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.result;

import java.io.IOException;
import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.io.StringWriter;

// Zeus imports
import org.enhydra.zeus.Result;

// JUnit imports
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 *  This class provides rudimentary tests for the StreamResult 
 *    class. 
 * </p>
 *
 * @author <a href="mailto:smarks@digisolutions.com">Spencer A Marks</a>
 * @version $Id: StreamResultTest.java,v 1.2 2001/04/17 01:57:49 brooke Exp $
 * @see TestCase
 */
public class StreamResultTest extends TestCase {

    /**
     * <p>
     *  Creates a new <code>StreamResultTest</code> instance.
     *    Reqiured by JUnit. <CODE>testName</CODE>
     *    is simply the name of the test.
     * </p>
     *
     * @param testName a <code>String</code> value
     */
    public StreamResultTest(String testName) {
        super(testName);
    }

    /**
     * <p>
     *  This method maeks it easier to call these
     *    tests dynamically.
     * </p>
     *
     * @return A <code>TestSuite</code> that corresponds to this 
     *         <code>TestCase</p>
     */
    public static Test suite(){
        return new TestSuite(StreamResultTest.class);
    }

    /**
     * <p>
     *  This method tests the various constructors 
     *    for <CODE>{@link StreamResult}</CODE>
     * </p>
     */
    public void testStreamResultConstructor() {
        OutputStream out = new ByteArrayOutputStream();
        StreamResult result = 
            new StreamResult(out, "file:///test/system/ID.xml");
        result = new StreamResult(out);
        StringWriter writer = new StringWriter();
        result = new StreamResult(writer);
    }

    /**
     * <p>
     *  Test the <CODE>{@link StreamResult#getSystemID()}</CODE>
     *    method. 
     * </p>
     */
    public void testGetSystemID() {
        OutputStream out = new ByteArrayOutputStream();
        String id = "file:///test/system/ID.xml";
        StreamResult result = new StreamResult(out, id);
        assertEquals(id, result.getSystemID());
    }

    /**
     * <p>
     *  Test the <CODE>{@link StreamResult#setSystemID()}</CODE>
     *    method. 
     * </p>
     */
      public void testSetSystemID() {
          OutputStream out = new ByteArrayOutputStream();
          StreamResult result = new StreamResult(out);
          String id = "file:///test/system/ID.xml";
          result.setSystemID(id);
          assertEquals(id, result.getSystemID());
        }
       
      /**
       * <p>
       *  Test the <CODE>{@link StreamResult#write()}</CODE> method.
       * </p>
       *
       * @param output a <code>String</code> value
       * @exception <code>IOException</code> - if an error occurs
       */
      public void testWrite()  {
          try {
              StringWriter writer = new StringWriter();
              StreamResult result = new StreamResult(writer);
              result.write("<testOutput>Some Test output</testOutput>");
          } catch( IOException e) {
              fail(e.getMessage());
          }
      }

    /**
     * <p>
     *  This main method allows the running of this 
     *    test standalone. 
     * </p>
     *
     * @param args a <code>String[]</code> value
     */
    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }    
}






