/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 * Tests that the <code>{@link Arguments}</code> class appropriately handles the
 * conversion of a string array of arguments into a Key/Value manageable list.
 * </p>
 * 
 * @author Brooke Hedrick
 * @version 1.0
 */
public class ArgumentsTest extends TestCase {
        
    /**
     * <p>
     * Constructs a new ArgumentsTest with the given name.
     * </p>
     *
     * @param name the name of the test.
     */
    public ArgumentsTest(String name) {
        super(name);
    }

    /**
     * <p>
     * Returns a <code>TestSuite</code> consisting of
     * <code>ArgumentsTest</code>.
     * </p>
     *
     * @return a <code>TestSuite</code> consisting of
     *         <code>ArgumentsTest</code>.
     */
    public static Test suite(){
        return new TestSuite(ArgumentsTest.class);
    }

    /**
     * <p>
     * Tests the constructor <code>{@link Arguments()}</code>.
     * </p>
     */
    public void testNoParameterContstructor() {
        Arguments arguments = new Arguments();
    }

    /**
     * <p>
     * Tests the constructor <code>{@link Arguments(String[] args)}</code>.
     * </p>
     */
    public void testStringArrayContstructor() {
        String[] args = 
            new String[] {"-file=/usr/src/dtd/song.dtd","-quiet=true"};
            
        Arguments arguments = new Arguments(args);
        
        String expected = "/usr/src/dtd/song.dtd";
        assertEquals("Argument 'file': " + arguments.getValue("file") + 
            ", expected: " + expected, arguments.getValue("file"), 
            expected);    

        expected = "true";
        assertEquals("Argument 'quiet': " + arguments.getValue("quiet") + 
            ", expected: " + expected, arguments.getValue("quiet"), 
            expected);
    }

    /**
     * <p>
     * Tests whether <code>{@link Arguments#setValue(String)}</code> sets
     * an argument value successfully by using 
     * {@link Arguments#getValue(String)} to check the value that was set.
     * </p>
     */
    public void testSetAndGetValue() {
        Arguments arguments = new Arguments();
        
        String expected = "testValue";
        arguments.setValue("testArgument", expected);
        assertEquals("Argument 'testArgument': " + 
            arguments.getValue("testArgument") + ", expected: " + 
            expected, arguments.getValue("testArgument"), expected);    
    }

    /**
     * <p>
     * Tests whether <code>{@link Arguments#hasValue(String)}</code> 
     * correctly determines if there is argument for the value passed.
     * </p>
     */
    public void testHasValue() {
        Arguments arguments = new Arguments();
        
        arguments.setValue("testArgument", "testValue");
    
        assert("The argument should have been found.", 
            arguments.hasValue("testArgument"));
            
        assert("The argument should not have been found.", 
            !arguments.hasValue("notFoundArgument"));
    }

    /**
     * <p>
     * Tests whether <code>{@link Arguments#setValues(String[])}</code> 
     * correctly sets multiple parameters from a String array.
     * </p>
     */
    public void testSetValues() {
        String[] args = 
            new String[] {"-file=/usr/src/dtd/song.dtd","-quiet=true"};
            
        Arguments arguments = new Arguments();
        arguments.setValues(args);
        
        String expected = "/usr/src/dtd/song.dtd";
        assertEquals("Argument 'file': " + arguments.getValue("file") + 
            ", expected: " + expected, arguments.getValue("file"), 
            expected);    

        expected = "true";
        assertEquals("Argument 'quiet': " + arguments.getValue("quiet") + 
            ", expected: " + expected, arguments.getValue("quiet"), 
            expected);
    }
 
    /**
     * <p>
     * Static entry point that allows this test to be run from the command line.
     * </p>
     */
    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }    

}

