/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 * Tests that the <code>{@link CapitalizationUtils}</code> class appropriately
 * coverts characters from lower to uppercase and the other way round
 * </p>
 *
 * @author Farhat Kaleem
 * @version 1.0
 */
public class CapitalizationUtilsTest extends TestCase {

    /**
     * <p>
     * Constructs a new CapitalizationUtilsTest with the given name.
     * </p>
     *
     * @param name the name of the test.
     */
    public CapitalizationUtilsTest(String name) {
        super(name);
    }

    /**
     * <p>
     * Returns a <code>TestSuite</code> consisting of
     * <code>CapitalizationUtilsTest</code>.
     * </p>
     *
     * @returns a <code>TestSuite</code> consisting of
     *         <code>CapitalizationUtilsTest</code>.
     */
    public static Test suite(){
        return new TestSuite(CapitalizationUtilsTest.class);
    }

    /**
     * <p>
     * Tests whether <code>{@link CapitalizationUtils#allLower(String)}</code>
     * converts all characters in a String to lowercase
     * </p>
     */
    public void testAllLower() {
        String [] someStrings = {"CanYouReadThisNow", "CANYOUREADTHISNOW"};
        String expected = "canyoureadthisnow";

        for (int i = 0; i < someStrings.length; i++) {
            assertEquals("actual: "+someStrings[i]+" expected: "+expected,
                expected, CapitalizationUtils.allLower(someStrings[i]));
        }
    }

    /**
     * <p>
     * Tests whether <code>{@link CapitalizationUtils#allLower(String)}</code>
     * converts all characters in a String to uppercase
     * </p>
     */
    public void testAllUpper() {
        String [] someStrings = {"CanYouReadThisNow", "canyoureadthisnow"};
        String expected = "CANYOUREADTHISNOW";

        for (int i = 0; i < someStrings.length; i++) {
            assertEquals("actual: "+someStrings[i]+" expected: "+expected,
                expected, CapitalizationUtils.allUpper(someStrings[i]));
        }
    }

    /**
     * <p>
     * Tests whether <code>{@link CapitalizationUtils#allLower(String)}</code>
     * converts the first character in the string to lowercase
     * </p>
     */
    public void testInitialLower() {
        String [] someStrings = {"CanYouReadThisNow", "CANYOUREADTHISNOW"};
        String [] expectedStrings = {"canYouReadThisNow", "cANYOUREADTHISNOW"};

        for (int i = 0; i < someStrings.length; i++) {
            assertEquals("actual: "+someStrings[i]+" expected: "+
                expectedStrings[i], expectedStrings[i],
                CapitalizationUtils.initialLower(someStrings[i]));
        }
    }

    /**
     * <p>
     * Tests whether <code>{@link CapitalizationUtils#allLower(String)}</code>
     * converts the first character in the string to uppercase
     * </p>
     */
    public void testInitialUpper() {
        String [] someStrings = {"canYouReadThisNow", "canyoureadthisnow"};
        String [] expectedStrings = {"CanYouReadThisNow", "Canyoureadthisnow"};

        for (int i = 0; i < someStrings.length; i++) {
            assertEquals("actual: "+someStrings[i]+" expected: "+
                expectedStrings[i], expectedStrings[i],
                CapitalizationUtils.initialUpper(someStrings[i]));
        }
    }

    /**
     * <p>
     * Tests whether <code>{@link CapitalizationUtils#allLower(String)}</code>
     * converts just the first character in the string to uppercase and
     * converts the rest to lowercase
     * </p>
     */
    public void testJustInitialUpper() {
        String [] someStrings = {"canYouReadThisNow", "canyoureadTHISnow"};
        String [] expectedStrings = {"Canyoureadthisnow", "Canyoureadthisnow"};

        for (int i = 0; i < someStrings.length; i++) {
            assertEquals("actual: "+someStrings[i]+" expected: "+
                expectedStrings[i], expectedStrings[i],
                CapitalizationUtils.justInitialUpper(someStrings[i]));
        }
    }

    /**
     * <p>
     * Static entry point that allows this test to be run from the command line.
     * </p>
     */
    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }

}

