/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.util.HashMap;
import java.util.Vector;

/**
 * <p>
 * Tests the <code>{@link ClassUtils}</code> class
 * </p>
 *
 * @author Farhat Kaleem
 * @version 1.0
 */
public class ClassUtilsTest extends TestCase {

    //this is an inner class just for testing in the method testGetParameter
    private class Test1 {

    }//

    //this is a second inner class just for testing in the method
    //testGetParameter
    private class Test2 {

    }//

    /**
     * <p>
     * Constructs a new ClassUtilsTest with the given name.
     * </p>
     *
     * @param name the name of the test.
     */
    public ClassUtilsTest(String name) {
        super(name);
    }

    /**
     * <p>
     * Returns a <code>TestSuite</code> consisting of
     * <code>ClassUtilsTest</code>.
     * </p>
     *
     * @returns a <code>TestSuite</code> consisting of
     *         <code>ClassUtilsTest</code>.
     */
    public static Test suite(){
        return new TestSuite(ClassUtilsTest.class);
    }

    /**
     * <p>
     * Tests whether <code>{@link ClassUtils#isCollectionClass(String)}</code>
     * correctly checks if the passed in parameter represents a Collection class
     * </p>
     */
    public void testIsCollectionClass() {
        String [] collectionClasses =
            { "java.util.Collection", "java.util.List", "java.util.LinkedList",
              "java.util.ArrayList", "java.util.Vector",
              "java.util.Stack", "java.util.Set", "java.util.SortedSet",
              "java.util.HashSet", "java.util.TreeSet" };

         //boolean expected = true;

        for (int i = 0; i < collectionClasses.length; i++) {
            assert("The class: '"+collectionClasses[i]+
                "' is a Collection class ",
            ClassUtils.isCollectionClass(collectionClasses[i]));
        }//for
    }

    /**
     * <p>
     * Tests whether
     * <code>{@link ClassUtils#getCollectionImplClass(String)}</code> correctly
     * returns the implementation class of a Collection interface
     * </p>
     */
    public void testGetCollectionImplClass() {
        String [] collectionClasses =
            { "java.util.Collection", "java.util.List", "java.util.LinkedList",
              "java.util.ArrayList", "java.util.Vector",
              "java.util.Stack", "java.util.Set", "java.util.SortedSet",
              "java.util.HashSet", "java.util.TreeSet" };

        String [] expectedClasses =
            { "java.util.LinkedList", "java.util.LinkedList",
              "java.util.LinkedList", "java.util.ArrayList",
              "java.util.Vector", "java.util.Stack", "java.util.HashSet",
              "java.util.SortedSet", "java.util.HashSet",
              "java.util.TreeSet" };

        //boolean expected = true;

        for (int i = 0; i < expectedClasses.length; i++) {
            assertEquals(expectedClasses[i],
                ClassUtils.getCollectionImplClass(collectionClasses[i]));
           //assertEquals("java.util.ArrayList",
           //      ClassUtils.getCollectionImplClass("java.util.ArrayList"));
        }//for
    }

    /**
     * <p>
     * Tests whether
     * <code>{@link ClassUtils#getParameter(String, Class)}</code> is returning
     *  the right object
     * </p>
     */
    public void testGetParameter() {
        Class [] paramTypes =
            { String.class, int.class, Integer.class, long.class, Long.class,
              float.class, Float.class, double.class, Double.class,
              boolean.class, Boolean.class };

        String [] values =
            { "string", "0", "0", "0", "0", "0.0f", "0.0f", "0.0d", "0.0d",
               "false", "false" };

        Object[] expected =
            { new String("string"), new Integer(0), new Integer(0),
              new Long(0), new Long(0), new Float(0.0f), new Float(0.0f),
              new Double(0.0d), new Double(0.0d), new Boolean(false),
              new Boolean(false) };

        for (int i = 0; i < paramTypes.length; i++) {
            assertEquals(expected[i], ClassUtils.getParameter(values[i],
                paramTypes[i]));
        }
    }

    /**
     * <p>
     * Static entry point that allows this test to be run from the command
     * line.
     * </p>
     */
    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }

}

